@@ -107,8 +107,8 @@ def callback(
         allow_404=True):
 
     def cb(response):
-        if response.code == 500:
-            raise ConsulException(response.body)
+        if response.code >= 500 and response.code < 600:
+            raise ConsulException("%d %s" % (response.code, response.body))
         if response.code == 403:
             raise ACLPermissionDenied(response.body)
         if response.code == 404 and not allow_404:
@@ -234,7 +234,9 @@ class Consul(object):
 
         def list(
                 self,
-                name=None):
+                name=None,
+                index=None,
+                wait=None):
             """
             Returns a tuple of (*index*, *events*)
                 Note: Since Consul's event protocol uses gossip, there is no
@@ -243,6 +245,15 @@ class Consul(object):
 
             *name* is the type of events to list, if None, lists all available.
 
+            *index* is the current event Consul index, suitable for making
+            subsequent calls to wait for changes since this query was last run.
+            Check https://consul.io/docs/agent/http/event.html#event_list for
+            more infos about indexes on events.
+
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. This parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
             Consul agents only buffer the most recent entries. The current
             buffer size is 256, but this value could change in the future.
 
@@ -264,6 +275,10 @@ class Consul(object):
             params = {}
             if name is not None:
                 params['name'] = name
+            if index:
+                params['index'] = index
+                if wait:
+                    params['wait'] = wait
 
             def callback(response):
                 data = json.loads(response.body)
@@ -1108,9 +1123,7 @@ class Consul(object):
                 '/v1/catalog/service/%s' % service, params=params)
 
     class Health(object):
-        # TODO: All of the health endpoints support blocking queries and all
-        # consistency modes
-        # TODO: still need to add node and checks endpoints
+        # TODO: All of the health endpoints support all consistency modes
         def __init__(self, agent):
             self.agent = agent
 
@@ -1162,6 +1175,41 @@ class Consul(object):
                 callback,
                 '/v1/health/service/%s' % service, params=params)
 
+        def checks(self, service, index=None, wait=None, dc=None):
+            """
+            Returns a tuple of (*index*, *checks*) with *checks* being the
+            checks associated with the service.
+
+            *service* is the name of the service being checked.
+
+            *index* is the current Consul index, suitable for making subsequent
+            calls to wait for changes since this query was last run.
+
+            *wait* the maximum duration to wait (e.g. '10s') to retrieve
+            a given index. this parameter is only applied if *index* is also
+            specified. the wait time by default is 5 minutes.
+
+            *dc* is the datacenter of the node and defaults to this agents
+            datacenter.
+
+            """
+            params = {}
+            if index:
+                params['index'] = index
+                if wait:
+                    params['wait'] = wait
+            dc = dc or self.agent.dc
+            if dc:
+                params['dc'] = dc
+
+            def callback(response):
+                data = json.loads(response.body)
+                return response.headers['X-Consul-Index'], data
+
+            return self.agent.http.get(
+                callback,
+                '/v1/health/checks/%s' % service, params=params)
+
         def state(self, name, index=None, wait=None, dc=None):
             """
             Returns a tuple of (*index*, *nodes*)
